@@ -1,6 +1,5 @@
 package GitLab::API::v4::Constants;
-
-$GitLab::API::v4::Constants::VERSION = '0.16';
+our $VERSION = '0.21';
 
 =encoding utf8
 
@@ -146,12 +145,17 @@ push @EXPORT_OK, '@GITLAB_SNIPPET_VISIBILITY_LEVELS';
 1;
 __END__
 
+=head1 SUPPORT
+
+See L<GitLab::API::v4/SUPPORT>.
+
 =head1 AUTHORS
 
-See L<GitLab::API::v4/AUTHOR> and L<GitLab::API::v4/CONTRIBUTORS>.
+See L<GitLab::API::v4/AUTHORS>.
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+See L<GitLab::API::v4/COPYRIGHT AND LICENSE>.
+
+=cut
 
