@@ -1,6 +1,5 @@
 package GitLab::API::v4::RESTClient;
-
-$GitLab::API::v4::RESTClient::VERSION = '0.16';
+our $VERSION = '0.21';
 
 =encoding utf8
 
@@ -19,18 +18,18 @@ source.
 
 =cut
 
-use Types::Standard -types;
-use Types::Common::String -types;
-use Types::Common::Numeric -types;
-use Log::Any qw( $log );
-use URI::Escape;
-use HTTP::Tiny;
+use Carp qw( croak );
 use HTTP::Tiny::Multipart;
+use HTTP::Tiny;
 use JSON;
-use URI;
-use Carp qw( croak confess );
-use Try::Tiny;
+use Log::Any qw( $log );
 use Path::Tiny;
+use Try::Tiny;
+use Types::Common::Numeric -types;
+use Types::Common::String -types;
+use Types::Standard -types;
+use URI::Escape;
+use URI;
 
 use Moo;
 use strictures 2;
@@ -90,7 +89,7 @@ sub _http_tiny_request {
 }
 
 sub request {
-    my ($self, $verb, $path, $path_vars, $options) = @_;
+    my ($self, $verb, $raw_path, $path_vars, $options) = @_;
 
     $options = { %{ $options || {} } };
     my $query = delete $options->{query};
@@ -98,6 +97,7 @@ sub request {
     my $headers = $options->{headers} = { %{ $options->{headers} || {} } };
 
     # Convert foo/:bar/baz into foo/%s/baz.
+    my $path = $raw_path;
     $path =~ s{:[^/]+}{%s}g;
     # sprintf will throw if the number of %s doesn't match the size of @$path_vars.
     # Might be nice to catch that and provide a better error message, but that should
@@ -169,6 +169,12 @@ sub request {
         return undef;
     }
 
+    # Special case for:
+    # https://github.com/bluefeet/GitLab-API-v4/issues/35#issuecomment-515533017
+    if ($res->{status} eq '403' and $verb eq 'GET' and $raw_path eq 'projects/:project_id/releases/:tag_name') {
+        return undef;
+    }
+
     if ($res->{success}) {
         my $decode = $options->{decode};
         $decode = 1 if !defined $decode;
@@ -200,12 +206,17 @@ sub request {
 1;
 __END__
 
+=head1 SUPPORT
+
+See L<GitLab::API::v4/SUPPORT>.
+
 =head1 AUTHORS
 
-See L<GitLab::API::v4/AUTHOR> and L<GitLab::API::v4/CONTRIBUTORS>.
+See L<GitLab::API::v4/AUTHORS>.
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+See L<GitLab::API::v4/COPYRIGHT AND LICENSE>.
+
+=cut
 
